@@ -272,8 +272,8 @@ module Rails
       def gem_for_database
         # %w( mysql postgresql sqlite3 oracle frontbase ibm_db sqlserver jdbcmysql jdbcsqlite3 jdbcpostgresql )
         case options[:database]
-        when "mysql"          then ["mysql2", [">= 0.3.18", "< 0.5"]]
-        when "postgresql"     then ["pg", ["~> 0.18"]]
+        when "mysql"          then ["mysql2", [">= 0.3.18", "< 0.6.0"]]
+        when "postgresql"     then ["pg", [">= 0.18", "< 2.0"]]
         when "oracle"         then ["activerecord-oracle_enhanced-adapter", nil]
         when "frontbase"      then ["ruby-frontbase", nil]
         when "sqlserver"      then ["activerecord-sqlserver-adapter", nil]
@@ -364,7 +364,7 @@ module Rails
         return [] if options[:skip_action_cable]
         comment = "Use Redis adapter to run Action Cable in production"
         gems = []
-        gems << GemfileEntry.new("redis", "~> 3.0", comment, {}, true)
+        gems << GemfileEntry.new("redis", "~> 4.0", comment, {}, true)
         gems
       end
 
